@@ -3,15 +3,15 @@
 
 from subprocess    import call
 
-from PyQt4.QtCore  import Qt, QObject, QSettings, QString, QVariant, \
-                          SIGNAL, SLOT
+from PyQt4.QtCore  import Qt, QObject, QSettings, QString, QStringList, \
+                          QVariant, SIGNAL, SLOT
 from PyQt4.QtGui   import QAbstractItemView, QComboBox, QDialog, \
                           QDialogButtonBox, QHBoxLayout, QLabel, QLineEdit, \
                           QListWidget, QMenuBar, QMessageBox, QPushButton, \
-                          QVBoxLayout, QWidget
+                          QStringListModel, QVBoxLayout, QWidget
 from ACE_file      import ACEFile;
 
-version = '0.0.6'
+version = '0.0.7'
 
 langLookup = {
     3: 'English (United Kingdom)',
@@ -34,6 +34,8 @@ langLookup = {
     52: 'Français (Québec)',
 }
 
+delModes = QStringList(('Normal', 'Confirm', 'OnClick'))
+
 class ACEAboutWindow(QDialog): #{{{1
     def __init__(self, parent): #{{{2
         QDialog.__init__(self, parent)
@@ -54,8 +56,64 @@ class ACEAboutWindow(QDialog): #{{{1
         lyt = QHBoxLayout(self)
         lyt.addWidget(txt)
 
+class ACEConfigWindow(QDialog): #{{{1
+    def __init__(self, parent): #{{{2
+        QDialog.__init__(self, parent)
+
+        self._parent = parent
+        self.setWindowTitle('Settings')
+
+        lyt = QVBoxLayout(self)
+
+        if parent.maemo:
+            from PyQt4.QtMaemo5 import QMaemo5ListPickSelector, QMaemo5ValueButton
+
+            lst = QStringListModel(delModes)
+
+            sel = QMaemo5ListPickSelector()
+            sel.setModel(lst)
+            sel.setCurrentIndex(delModes.indexOf(parent.delMode))
+
+            btn = QMaemo5ValueButton('Delete mode')
+            btn.setPickSelector(sel)
+
+            lyt.addWidget(btn)
+
+            QObject.connect(sel, SIGNAL('selected(QString)'), self.changeDeleteMode)
+
+            self._lst = lst
+            self._sel = sel
+        else:
+            boxLyt = QHBoxLayout()
+
+            lbl = QLabel('Delete mode:')
+
+            btn = QComboBox()
+            btn.addItems(delModes)
+            btn.setCurrentIndex(delModes.indexOf(parent.delMode))
+
+            boxLyt.addWidget(lbl)
+            boxLyt.addWidget(btn)
+            lyt.addLayout(boxLyt)
+
+            QObject.connect(btn, SIGNAL('currentIndexChanged(int)'), self.changeDeleteModeIndex)
+
+        btns = QDialogButtonBox(QDialogButtonBox.Ok|QDialogButtonBox.Cancel)
+        QObject.connect(btns, SIGNAL('accepted()'), self, SLOT('accept()'))
+        QObject.connect(btns, SIGNAL('rejected()'), self, SLOT('reject()'))
+        lyt.addWidget(btns)
+
+    def changeDeleteModeIndex(self, modeIndex): #{{{1
+        mode = delModes[modeIndex]
+
+        self.changeDeleteMode(mode)
+
+    def changeDeleteMode(self, mode): #{{{1
+        if mode != self._parent.newDelMode:
+            self._parent.newDelMode = mode
+
 class ACEMainWindow(QWidget): #{{{1
-    _maemo = False
+    maemo = False
     _dict  = None
     _dicts = {}
 
@@ -64,16 +122,21 @@ class ACEMainWindow(QWidget): #{{{1
 
         try:
             from PyQt4.QtMaemo5 import QMaemo5InformationBox
-            self._maemo = True
+            self.maemo = True
             self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
         except:
             pass
 
         # Set to the N900 screen size to aid testing
         self.setMinimumSize(800, 480)
-        self.setWindowTitle('AutoComplete Editor')
+        self.setWindowTitle('Auto-Complete Editor')
 
         self._settings = QSettings('Auto-Complete Editor', 'Auto-Complete Editor')
+        self.delMode = self._settings.value('DeleteMode').toString()
+        if self.delMode == '':
+            self.delMode = 'Normal'
+
+        self.newDelMode = self.delMode
 
         QHBoxLayout(self)
 
@@ -88,6 +151,23 @@ class ACEMainWindow(QWidget): #{{{1
         aboutWin = ACEAboutWindow(self)
         aboutWin.exec_()
 
+    def config(self): #{{{2
+        configWin = ACEConfigWindow(self)
+        if configWin.exec_() == QDialog.Rejected:
+            self.newDelMode = self.delMode
+
+        if self.newDelMode != self.delMode:
+            if self.delMode == 'OnClick':
+                self._delBtn.setEnabled(True)
+                QObject.disconnect(self._listView, SIGNAL('itemClicked(QListWidgetItem *)'), self.deleteEntry)
+
+            if self.newDelMode == 'OnClick':
+                self._delBtn.setEnabled(False)
+                QObject.connect(self._listView, SIGNAL('itemClicked(QListWidgetItem *)'), self.deleteEntry)
+
+            self.delMode = self.newDelMode
+            self._settings.setValue('DeleteMode', self.delMode)
+
     def addEntry(self, checked): #{{{2
         dlg = QDialog(self)
         dlg.setWindowTitle('Enter new value')
@@ -118,17 +198,28 @@ class ACEMainWindow(QWidget): #{{{1
         self._dicts[self._curLang].append(lwrText)
 
     def clearEntries(self, checked): #{{{2
+        if self.delMode == 'Confirm':
+            if QMessageBox.question(self, 'Delete confirmation', 'Please confirm that you want to delete all entries', QMessageBox.Ok|QMessageBox.Cancel) != QMessageBox.Ok:
+                return
+
         self._listView.clear()
         self._dicts[self._curLang].clear()
 
     def deleteEntries(self, checked): #{{{2
+        if self.delMode == 'Confirm':
+            if QMessageBox.question(self, 'Delete confirmation', QString('Please confirm that you want to delete the %1 selected entries').arg(len(self._listView.selectedItems())), QMessageBox.Ok|QMessageBox.Cancel) != QMessageBox.Ok:
+                return
+
         for entry in self._listView.selectedItems():
-            row = self._listView.row(entry)
-            self._listView.takeItem(row)
-            val = entry.data(Qt.DisplayRole).toString()
+            self.deleteEntry(entry)
 
-            self._dicts[self._curLang].removeAt(self._dicts[self._curLang].indexOf(val))
+    def deleteEntry(self, entry): #{{{2
+        row = self._listView.row(entry)
+        self._listView.takeItem(row)
+        val = entry.data(Qt.DisplayRole).toString()
 
+        self._dicts[self._curLang].removeAt(self._dicts[self._curLang].indexOf(val))
+        
     def loadDictionary(self, row): #{{{2
         self._listView.clear()
 
@@ -142,7 +233,7 @@ class ACEMainWindow(QWidget): #{{{1
         self.loadData()
 
     def saveChanges(self, checked): #{{{2
-        if self._maemo:
+        if self.maemo:
             self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
 
         langs = []
@@ -164,7 +255,7 @@ class ACEMainWindow(QWidget): #{{{1
 
         call(['/usr/bin/killall', 'hildon-input-method'])
 
-        if self._maemo:
+        if self.maemo:
             from PyQt4.QtMaemo5 import QMaemo5InformationBox
             QMaemo5InformationBox.information(self, 'Dictionary saved', QMaemo5InformationBox.DefaultTimeout)
             self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
@@ -174,6 +265,8 @@ class ACEMainWindow(QWidget): #{{{1
     def setupMenu(self): #{{{2
         menu = QMenuBar()
 
+        act = menu.addAction('Settings')
+        QObject.connect(act, SIGNAL('triggered()'), self.config)
         act = menu.addAction('About')
         QObject.connect(act, SIGNAL('triggered()'), self.about)
         self.layout().setMenuBar(menu)
@@ -188,12 +281,18 @@ class ACEMainWindow(QWidget): #{{{1
         self._listView.setSelectionMode(QAbstractItemView.MultiSelection)
         self._listView.setSortingEnabled(True)
 
+        if self.delMode == 'OnClick':
+            QObject.connect(self._listView, SIGNAL('itemClicked(QListWidgetItem *)'), self.deleteEntry)
+
         btnBox = QDialogButtonBox()
         btnBox.setOrientation(Qt.Vertical)
         btn = btnBox.addButton('Delete all', QDialogButtonBox.ActionRole)
         QObject.connect(btn, SIGNAL('clicked(bool)'), self.clearEntries)
         btn = btnBox.addButton('Delete selected', QDialogButtonBox.ActionRole)
         QObject.connect(btn, SIGNAL('clicked(bool)'), self.deleteEntries)
+        if self.delMode == 'OnClick':
+            btn.setEnabled(False)
+        self._delBtn = btn
         btn = btnBox.addButton('Add entry', QDialogButtonBox.ActionRole)
         QObject.connect(btn, SIGNAL('clicked(bool)'), self.addEntry)
         btn = btnBox.addButton('Save changes', QDialogButtonBox.AcceptRole)
@@ -209,12 +308,12 @@ class ACEMainWindow(QWidget): #{{{1
         self.layout().addWidget(btnBox)
 
         # Clear the progress indicator
-        if self._maemo:
+        if self.maemo:
             self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
 
     def loadData(self): #{{{2
         updateSpinner = False
-        if self._maemo and not self.testAttribute(Qt.WA_Maemo5ShowProgressIndicator):
+        if self.maemo and not self.testAttribute(Qt.WA_Maemo5ShowProgressIndicator):
             updateSpinner = True
             self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
 
